from typing import Any, Dict, Optional, Union

from fastapi import HTTPException
from fastapi.encoders import jsonable_encoder
from sqlalchemy.orm import Session

from crud.base import CRUDBase
from models.folders import Folder
from schemas import FolderUpdate, FolderCreate


class CRUDFolder(CRUDBase[Folder, FolderCreate, FolderUpdate]):
    def create_with_folder(
            self, db: Session, *, obj_in: FolderCreate, user_id: int
    ) -> Folder:
        obj_in_data = jsonable_encoder(obj_in)
        db_obj = self.model(**obj_in_data, user_id=user_id)
        db.add(db_obj)
        db.commit()
        db.refresh(db_obj)
        return db_obj





folder = CRUDFolder(Folder)
